import 'dotenv/config';
import { drizzle } from 'drizzle-orm/bun-sqlite';
import { publisherTable, sourceTable } from './schema';
import { publishersData, sourcesData } from './data'

const db = drizzle({ connection: { source: process.env.DB_FILE_NAME! } });

async function deleteData() {
  await db.delete(publisherTable)
  console.log('- Publishers Deleted')

  await db.delete(sourceTable)
  console.log('- Sources Deleted')
}

async function seedData() {
  const publishers = await db.insert(publisherTable).values(publishersData()).returning()
  console.log('- Publishers Created')

  const sources = await db.insert(sourceTable).values(sourcesData(publishers)).returning()
  console.log('- Sources Created', sources)
}

(async () => {
  console.log('Deleting Existing Data...')
  await deleteData();
  console.log('Data Deleted!\n=====\nSeeding Data...')
  await seedData();
  console.log('Data Seeded!')
})().catch(err => {
  console.error(err);
});
